@@ -39,7 +39,7 @@ __copyright__ = """
 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "0.0.2"
+__version__ = "0.1.0"
 modname = "attr_utils"
 pypi_name = "attr_utils"
 import_name = "attr_utils"
@@ -51,7 +51,7 @@ github_username = "domdfcoding"
 web = github_url = "https://github.com/domdfcoding/attr_utils"
 repo_root = pathlib.Path(__file__).parent
 install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
-extras_require = {'sphinx': ['sphinx>=3.0.3', 'sphinx_autodoc_typehints>=1.11.0'], 'all': ['sphinx>=3.0.3', 'sphinx_autodoc_typehints>=1.11.0']}
+extras_require = {'sphinx': ['sphinx>=3.0.3', 'sphinx_toolbox>=0.6.0'], 'all': ['sphinx>=3.0.3', 'sphinx_toolbox>=0.6.0']}
 
 
 
